Class: Aws::Repostspace::Waiters::ChannelCreated
- Inherits:
-
Object
- Object
- Aws::Repostspace::Waiters::ChannelCreated
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-repostspace/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ChannelCreated
constructor
A new instance of ChannelCreated.
-
#wait(params = {}) ⇒ Types::GetChannelOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ChannelCreated
Returns a new instance of ChannelCreated.
87 88 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 87
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
125 126 127 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 125 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetChannelOutput
Returns a response object which responds to the following methods:
- #space_id => String
- #channel_id => String
- #channel_name => String
- #channel_description => String
- #create_date_time => Time
- #delete_date_time => Time
- #channel_roles => Hash<String,Array<String>>
- #channel_status => String
120 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 120
def wait: (
|