Class: Aws::Repostspace::Waiters::SpaceDeleted
- Inherits:
-
Object
- Object
- Aws::Repostspace::Waiters::SpaceDeleted
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-repostspace/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ SpaceDeleted
constructor
A new instance of SpaceDeleted.
-
#wait(params = {}) ⇒ Types::GetSpaceOutput
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ SpaceDeleted
Returns a new instance of SpaceDeleted.
242 243 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 242
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
285 286 287 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 285 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::GetSpaceOutput
Returns a response object which responds to the following methods:
- #space_id => String
- #arn => String
- #name => String
- #status => String
- #configuration_status => String
- #client_id => String
- #identity_store_id => String
- #application_arn => String
- #description => String
- #vanity_domain_status => String
- #vanity_domain => String
- #random_domain => String
- #customer_role_arn => String
- #create_date_time => Time
- #delete_date_time => Time
- #tier => String
- #storage_limit => Integer
- #user_admins => Array<String>
- #group_admins => Array<String>
- #roles => Hash<String,Array<String>>
- #user_kms_key => String
- #user_count => Integer
- #content_size => Integer
- #supported_email_domains => Types::SupportedEmailDomainsStatus
280 |
# File 'lib/aws-sdk-repostspace/waiters.rb', line 280
def wait: (
|