Class: Aws::Repostspace::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::Repostspace::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-repostspace/client.rb
Overview
An API client for Repostspace. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::Repostspace::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_add_channel_role_to_accessors(params = {}) ⇒ Types::BatchAddChannelRoleToAccessorsOutput
Add role to multiple users or groups in a private re:Post channel.
-
#batch_add_role(params = {}) ⇒ Types::BatchAddRoleOutput
Add a role to multiple users or groups in a private re:Post.
-
#batch_remove_channel_role_from_accessors(params = {}) ⇒ Types::BatchRemoveChannelRoleFromAccessorsOutput
Remove a role from multiple users or groups in a private re:Post channel.
-
#batch_remove_role(params = {}) ⇒ Types::BatchRemoveRoleOutput
Remove a role from multiple users or groups in a private re:Post.
-
#create_channel(params = {}) ⇒ Types::CreateChannelOutput
Creates a channel in an AWS re:Post Private private re:Post.
-
#create_space(params = {}) ⇒ Types::CreateSpaceOutput
Creates an AWS re:Post Private private re:Post.
-
#delete_space(params = {}) ⇒ Struct
Deletes an AWS re:Post Private private re:Post.
-
#deregister_admin(params = {}) ⇒ Struct
Removes the user or group from the list of administrators of the private re:Post.
-
#get_channel(params = {}) ⇒ Types::GetChannelOutput
Displays information about a channel in a private re:Post.
-
#get_space(params = {}) ⇒ Types::GetSpaceOutput
Displays information about the AWS re:Post Private private re:Post.
-
#list_channels(params = {}) ⇒ Types::ListChannelsOutput
Returns the list of channel within a private re:Post with some information about each channel.
-
#list_spaces(params = {}) ⇒ Types::ListSpacesOutput
Returns a list of AWS re:Post Private private re:Posts in the account with some information about each private re:Post.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags that are associated with the AWS re:Post Private resource specified by the resourceArn.
-
#register_admin(params = {}) ⇒ Struct
Adds a user or group to the list of administrators of the private re:Post.
-
#send_invites(params = {}) ⇒ Struct
Sends an invitation email to selected users and groups.
-
#tag_resource(params = {}) ⇒ Struct
Associates tags with an AWS re:Post Private resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the association of the tag with the AWS re:Post Private resource.
-
#update_channel(params = {}) ⇒ Struct
Modifies an existing channel.
-
#update_space(params = {}) ⇒ Struct
Modifies an existing AWS re:Post Private private re:Post.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-repostspace/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1598 1599 1600 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1598 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1601 1602 1603 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1601 def errors_module Errors end |
Instance Method Details
#batch_add_channel_role_to_accessors(params = {}) ⇒ Types::BatchAddChannelRoleToAccessorsOutput
Add role to multiple users or groups in a private re:Post channel.
539 540 541 542 |
# File 'lib/aws-sdk-repostspace/client.rb', line 539 def batch_add_channel_role_to_accessors(params = {}, = {}) req = build_request(:batch_add_channel_role_to_accessors, params) req.send_request() end |
#batch_add_role(params = {}) ⇒ Types::BatchAddRoleOutput
Add a role to multiple users or groups in a private re:Post.
601 602 603 604 |
# File 'lib/aws-sdk-repostspace/client.rb', line 601 def batch_add_role(params = {}, = {}) req = build_request(:batch_add_role, params) req.send_request() end |
#batch_remove_channel_role_from_accessors(params = {}) ⇒ Types::BatchRemoveChannelRoleFromAccessorsOutput
Remove a role from multiple users or groups in a private re:Post channel.
669 670 671 672 |
# File 'lib/aws-sdk-repostspace/client.rb', line 669 def batch_remove_channel_role_from_accessors(params = {}, = {}) req = build_request(:batch_remove_channel_role_from_accessors, params) req.send_request() end |
#batch_remove_role(params = {}) ⇒ Types::BatchRemoveRoleOutput
Remove a role from multiple users or groups in a private re:Post.
731 732 733 734 |
# File 'lib/aws-sdk-repostspace/client.rb', line 731 def batch_remove_role(params = {}, = {}) req = build_request(:batch_remove_role, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1452 1453 1454 1455 1456 1457 1458 1459 1460 1461 1462 1463 1464 1465 1466 1467 1468 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1452 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::Repostspace') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-repostspace' context[:gem_version] = '1.37.0' Seahorse::Client::Request.new(handlers, context) end |
#create_channel(params = {}) ⇒ Types::CreateChannelOutput
Creates a channel in an AWS re:Post Private private re:Post.
782 783 784 785 |
# File 'lib/aws-sdk-repostspace/client.rb', line 782 def create_channel(params = {}, = {}) req = build_request(:create_channel, params) req.send_request() end |
#create_space(params = {}) ⇒ Types::CreateSpaceOutput
Creates an AWS re:Post Private private re:Post.
849 850 851 852 |
# File 'lib/aws-sdk-repostspace/client.rb', line 849 def create_space(params = {}, = {}) req = build_request(:create_space, params) req.send_request() end |
#delete_space(params = {}) ⇒ Struct
Deletes an AWS re:Post Private private re:Post.
871 872 873 874 |
# File 'lib/aws-sdk-repostspace/client.rb', line 871 def delete_space(params = {}, = {}) req = build_request(:delete_space, params) req.send_request() end |
#deregister_admin(params = {}) ⇒ Struct
Removes the user or group from the list of administrators of the private re:Post.
898 899 900 901 |
# File 'lib/aws-sdk-repostspace/client.rb', line 898 def deregister_admin(params = {}, = {}) req = build_request(:deregister_admin, params) req.send_request() end |
#get_channel(params = {}) ⇒ Types::GetChannelOutput
Displays information about a channel in a private re:Post.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* channel_created
* channel_deleted
975 976 977 978 |
# File 'lib/aws-sdk-repostspace/client.rb', line 975 def get_channel(params = {}, = {}) req = build_request(:get_channel, params) req.send_request() end |
#get_space(params = {}) ⇒ Types::GetSpaceOutput
Displays information about the AWS re:Post Private private re:Post.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* space_created
* space_deleted
1061 1062 1063 1064 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1061 def get_space(params = {}, = {}) req = build_request(:get_space, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsOutput
Returns the list of channel within a private re:Post with some information about each channel.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1145 1146 1147 1148 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1145 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_spaces(params = {}) ⇒ Types::ListSpacesOutput
Returns a list of AWS re:Post Private private re:Posts in the account with some information about each private re:Post.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1202 1203 1204 1205 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1202 def list_spaces(params = {}, = {}) req = build_request(:list_spaces, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags that are associated with the AWS re:Post Private resource specified by the resourceArn. The only resource that can be tagged is a private re:Post.
1233 1234 1235 1236 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1233 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#register_admin(params = {}) ⇒ Struct
Adds a user or group to the list of administrators of the private re:Post.
1260 1261 1262 1263 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1260 def register_admin(params = {}, = {}) req = build_request(:register_admin, params) req.send_request() end |
#send_invites(params = {}) ⇒ Struct
Sends an invitation email to selected users and groups.
1294 1295 1296 1297 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1294 def send_invites(params = {}, = {}) req = build_request(:send_invites, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates tags with an AWS re:Post Private resource. Currently, the only resource that can be tagged is the private re:Post. If you specify a new tag key for the resource, the tag is appended to the list of tags that are associated with the resource. If you specify a tag key that’s already associated with the resource, the new tag value that you specify replaces the previous value for that tag.
1329 1330 1331 1332 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1329 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the association of the tag with the AWS re:Post Private resource.
1356 1357 1358 1359 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1356 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_channel(params = {}) ⇒ Struct
Modifies an existing channel.
1401 1402 1403 1404 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1401 def update_channel(params = {}, = {}) req = build_request(:update_channel, params) req.send_request() end |
#update_space(params = {}) ⇒ Struct
Modifies an existing AWS re:Post Private private re:Post.
1443 1444 1445 1446 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1443 def update_space(params = {}, = {}) req = build_request(:update_space, params) req.send_request() end |
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
## Basic Usage
A waiter will call an API operation until:
-
It is successful
-
It enters a terminal state
-
It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
## Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
## Valid Waiters
The following table lists the valid waiter names, the operations they call, and the default ‘:delay` and `:max_attempts` values.
| waiter_name | params | :delay | :max_attempts | | ————— | ——————– | ——– | ————- | | channel_created | #get_channel | 2 | 60 | | channel_deleted | #get_channel | 2 | 60 | | space_created | #get_space | 300 | 24 | | space_deleted | #get_space | 300 | 24 |
1561 1562 1563 1564 1565 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1561 def wait_until(waiter_name, params = {}, = {}) w = waiter(waiter_name, ) yield(w.waiter) if block_given? # deprecated w.wait(params) end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1569 1570 1571 |
# File 'lib/aws-sdk-repostspace/client.rb', line 1569 def waiter_names waiters.keys end |